@@ -185,7 +185,7 @@ $translations = array(
 	'Save and continue edit' => 'Mentés és szerkesztés folytatása',
 	'original' => 'eredeti',
 	'%d item(s) have been affected.' => array('%d tétel érintett.', '%d tétel érintett.', '%d tétel érintett.'),
-	'whole result' => 'összes eredményt mutatása',
+	'Whole result' => 'Összes eredményt mutatása',
 	'Tables have been dropped.' => 'Táblák eldobva.',
 	'Clone' => 'Klónoz',
 	'Partition by' => 'Particionálás ezzel',
