@@ -184,7 +184,7 @@ $translations = array(
 	'Save and continue edit' => '저장하고 계속',
 	'original' => '원래',
 	'%d item(s) have been affected.' => '%d를 갱신했습니다.',
-	'whole result' => '모든 결과',
+	'Whole result' => '모든 결과',
 	'Tables have been dropped.' => '테이블을 삭제했습니다.',
 	'Clone' => '복제',
 	'Maximum number of allowed fields exceeded. Please increase %s.' => '정의 가능한 최대 필드 수를 초과했습니다. %s를 늘리십시오.',
