@@ -187,7 +187,7 @@ $translations = array(
 	'Move to other database' => 'Presunúť do inej databázy',
 	'Move' => 'Presunúť',
 	'%d item(s) have been affected.' => '%d položiek bolo ovplyvnených.',
-	'whole result' => 'celý výsledok',
+	'Whole result' => 'Celý výsledok',
 	'Clone' => 'Klonovať',
 	'Partition by' => 'Rozdeliť podľa',
 	'Partitions' => 'Oddiely',
