@@ -186,7 +186,7 @@ $translations = array(
 	'original' => 'ต้นฉบับ',
 	'Tables have been dropped.' => 'ตารางถูกลบแล้ว.',
 	'%d item(s) have been affected.' => 'มี %d รายการถูกดำเนินการแล้ว.',
-	'whole result' => 'รวมผล',
+	'Whole result' => 'รวมผล',
 	'Clone' => 'ทำซ้ำ',
 	'Maximum number of allowed fields exceeded. Please increase %s.' => 'จำนวนสูงสุดของฟิลด์อนุญาตให้เกิน กรุณาเพิ่มอีก %s.',
 	'Partition by' => 'พาร์ทิชันโดย',
