@@ -1,20 +1,20 @@
 <?php
 $TYPE = $_GET["type"];
+$row = $_POST;
 
 if ($_POST && !$error) {
 	$link = substr(ME, 0, -1);
 	if ($_POST["drop"]) {
 		query_redirect("DROP TYPE " . idf_escape($TYPE), $link, lang('Type has been dropped.'));
 	} else {
-		query_redirect("CREATE TYPE " . idf_escape($_POST["name"]) . " $_POST[as]", $link, lang('Type has been created.'));
+		query_redirect("CREATE TYPE " . idf_escape(trim($row["name"])) . " $row[as]", $link, lang('Type has been created.'));
 	}
 }
 
 page_header($TYPE != "" ? lang('Alter type') . ": " . h($TYPE) : lang('Create type'), $error);
 
-$row = $_POST;
 if (!$row) {
-	$row = array("as" => "AS ");
+	$row["as"] = "AS ";
 }
 ?>
 
@@ -22,9 +22,9 @@ if (!$row) {
 <p>
 <?php
 if ($TYPE != "") {
-	echo "<input type='submit' name='drop' value='" . lang('Drop') . "'" . confirm() . ">\n";
+	echo "<input type='submit' name='drop' value='" . lang('Drop') . "'>" . confirm(lang('Drop %s?', $TYPE)) . "\n";
 } else {
-	echo "<input name='name' value='" . h($row['name']) . "'>\n";
+	echo "<input name='name' value='" . h($row['name']) . "' autocapitalize='off'>\n";
 	textarea("as", $row["as"]);
 	echo "<p><input type='submit' value='" . lang('Save') . "'>\n";
 }
