@@ -14,7 +14,7 @@ class AdminerDumpJson {
 		return array('json' => 'JSON');
 	}
 
-	function dumpTable($table, $style, $is_view = false) {
+	function dumpTable($table, $style, $is_view = 0) {
 		if ($_POST["format"] == "json") {
 			return true;
 		}
